#include "lightbook.h"
#include <stdio.h>

int main(){
    person *list=0;
    /* Test inserimento */
    list=insert_person(list, "Paolino", "Paperino");
    list=insert_person(list, "Gastone", "Paperone");
    list=insert_person(list, "Pico", "De Paperis");
    list=insert_person(list, "Paperone", "De Paperoni");
    list=insert_person(list, "Pietro", "Gambadilegno");
    insert_friend(
            search(list,"Paolino", "Paperino"),
            search(list,"Pico","De Paperis")
    );
    insert_friend(
            search(list,"Gastone", "Paperone"),
            search(list,"Pico","De Paperis")
    );
    insert_friend(
            search(list,"Gastone", "Paperone"),
            search(list,"Paperone","De Paperoni")
    );

    /* Verifica contenuto */
    list=sort(list);
    printf("Contenuto della lista:\n");
    print(list);

    printf("\nAmici di Paperino:\n");
    print_relation(search(list,"Paolino", "Paperino"));

    reset_visit(list);
    list=delete_person(list, "Paolino", "Paperino");

    printf("\nAmici di Gastone:\n");
    print_relation(search(list,"Gastone", "Paperone"));
}
